lotka: Lotka's law coefficient estimation

View source: R/lotka.R

lotkaR Documentation

Lotka's law coefficient estimation

Description

It estimates Lotka's law coefficients for scientific productivity and tests the goodness of fit.

Usage

lotka(M)

Arguments

M

is an object of the class 'bibliometrixDB'.

Details

Lotka's Law, first formulated by Alfred J. Lotka in 1926, describes the frequency distribution of scientific productivity among authors. The law states that the number of authors producing n publications is approximately C / n^\beta, where C is a constant and \beta is the productivity exponent.

In the original formulation, Lotka proposed that \beta = 2, meaning that the number of authors who publish n papers is approximately 1/n^2 of those who publish one paper. The function estimates both the empirical \beta via regression and tests the fit of the theoretical distribution (\beta = 2) using a Kolmogorov-Smirnov test.

Reference:
Lotka, A. J. (1926). The frequency distribution of scientific productivity. Journal of the Washington Academy of Sciences, 16(12), 317-323.

Value

The function lotka returns a list containing the following objects:

AuthorProd Authors' Productivity frequency table
g Lotka's law plot in ggplot2 format (with logo)
g_shiny Lotka's law plot for biblioshiny (without logo)
stat list of statistical results (Beta, C, R2, KS tests)
Beta Beta coefficient (estimated)
C Constant coefficient
R2 Goodness of Fit (R-squared)
fitted Fitted Values
p.value p-value of KS test (theoretical Beta=2)

See Also

biblioAnalysis function for bibliometric analysis

summary method for class 'bibliometrix'

Examples

data(management, package = "bibliometrixData")
L <- lotka(management)
L


bibliometrix documentation built on April 9, 2026, 9:06 a.m.