View source: R/loadBookDataset.R
| loadBookDataset | R Documentation |
Downloads and caches the management collection dataset used in the book
"Science Mapping Analysis - A primer with Biblioshiny"
by Massimo Aria and Corrado Cuccurullo (McGraw-Hill, 2026).
The dataset is downloaded from GitHub on first use and
cached locally in ~/.bibliometrix/ for subsequent calls.
loadBookDataset(force_download = FALSE)
force_download |
Logical. If |
The dataset contains a comprehensive collection of original research articles, written in English, that employ bibliometric or scientometric methods within management and business fields, as indexed by Web of Science, over the period 1985–2025.
A bibliometrix data frame containing the book dataset.
Aria, M., & Cuccurullo, C. (2026). Science Mapping Analysis - A primer with Biblioshiny. McGraw-Hill. ISBN: 978-88-386-2297-7.
## Not run:
M <- loadBookDataset()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.