Learn R Programming

bibliometrix (version 5.4.1)

loadBookDataset: Load the Biblioshiny Book Dataset

Description

Downloads and caches the management collection dataset used in the book "Science Mapping Analysis - A primer with Biblioshiny" by Massimo Aria and Corrado Cuccurullo (McGraw-Hill, 2026). The dataset is downloaded from GitHub on first use and cached locally in ~/.bibliometrix/ for subsequent calls.

Usage

loadBookDataset(force_download = FALSE)

Value

A bibliometrix data frame containing the book dataset.

Arguments

force_download

Logical. If TRUE, re-downloads the dataset even if a cached copy exists locally. Default is FALSE.

Details

The dataset contains a comprehensive collection of original research articles, written in English, that employ bibliometric or scientometric methods within management and business fields, as indexed by Web of Science, over the period 1985--2025.

References

Aria, M., & Cuccurullo, C. (2026). Science Mapping Analysis - A primer with Biblioshiny. McGraw-Hill. ISBN: 978-88-386-2297-7.

Examples

Run this code
if (FALSE) {
M <- loadBookDataset()
}

Run the code above in your browser using DataLab