Learn R Programming

bibliometrix (version 5.4.1)

lotka: Lotka's law coefficient estimation

Description

It estimates Lotka's law coefficients for scientific productivity and tests the goodness of fit.

Usage

lotka(M)

Value

The function lotka returns a list containing the following objects:

AuthorProdAuthors' Productivity frequency table
gLotka's law plot in ggplot2 format (with logo)
g_shinyLotka's law plot for biblioshiny (without logo)
statlist of statistical results (Beta, C, R2, KS tests)
BetaBeta coefficient (estimated)
CConstant coefficient
R2Goodness of Fit (R-squared)
fittedFitted Values
p.valuep-value of KS test (theoretical Beta=2)

Arguments

M

is an object of the class 'bibliometrixDB'.

Details

Lotka's Law, first formulated by Alfred J. Lotka in 1926, describes the frequency distribution of scientific productivity among authors. The law states that the number of authors producing \(n\) publications is approximately \(C / n^\beta\), where \(C\) is a constant and \(\beta\) is the productivity exponent.

In the original formulation, Lotka proposed that \(\beta = 2\), meaning that the number of authors who publish \(n\) papers is approximately \(1/n^2\) of those who publish one paper. The function estimates both the empirical \(\beta\) via regression and tests the fit of the theoretical distribution (\(\beta = 2\)) using a Kolmogorov-Smirnov test.

Reference:
Lotka, A. J. (1926). The frequency distribution of scientific productivity. Journal of the Washington Academy of Sciences, 16(12), 317-323.

See Also

biblioAnalysis function for bibliometric analysis

summary method for class 'bibliometrix'

Examples

Run this code
data(management, package = "bibliometrixData")
L <- lotka(management)
L

Run the code above in your browser using DataLab