It estimates Lotka's law coefficients for scientific productivity and tests the goodness of fit.
lotka(M)The function lotka returns a list containing the following objects:
AuthorProd | Authors' Productivity frequency table | |
g | Lotka's law plot in ggplot2 format (with logo) | |
g_shiny | Lotka's law plot for biblioshiny (without logo) | |
stat | list of statistical results (Beta, C, R2, KS tests) | |
Beta | Beta coefficient (estimated) | |
C | Constant coefficient | |
R2 | Goodness of Fit (R-squared) | |
fitted | Fitted Values | |
p.value | p-value of KS test (theoretical Beta=2) |
is an object of the class 'bibliometrixDB'.
Lotka's Law, first formulated by Alfred J. Lotka in 1926, describes the frequency distribution
of scientific productivity among authors. The law states that the number of authors producing
\(n\) publications is approximately \(C / n^\beta\), where \(C\) is a constant and
\(\beta\) is the productivity exponent.
In the original formulation, Lotka proposed that \(\beta = 2\), meaning that the number of
authors who publish \(n\) papers is approximately \(1/n^2\) of those who publish one paper.
The function estimates both the empirical \(\beta\) via regression and tests the fit of
the theoretical distribution (\(\beta = 2\)) using a Kolmogorov-Smirnov test.
Reference:
Lotka, A. J. (1926). The frequency distribution of scientific productivity. Journal of the
Washington Academy of Sciences, 16(12), 317-323.
biblioAnalysis function for bibliometric analysis
summary method for class 'bibliometrix'
data(management, package = "bibliometrixData")
L <- lotka(management)
L
Run the code above in your browser using DataLab